[GRASS-SVN] r33769 - in grass/trunk: display/d.zoom doc/vector/v.example general/g.access general/g.proj gui/wxpython/vdigit imagery/i.cluster imagery/i.fft imagery/i.ifft imagery/i.ortho.photo/photo.2target imagery/i.zc lib/gis lib/gmath lib/gpde lib/proj lib/vector/Vlib raster/r.cost raster/r.distance raster/r.lake raster/r.random.cells raster/r.texture raster/r.walk raster/simwe/r.sim.sediment raster/wildfire/r.spread raster/wildfire/r.spreadpath vector/lidar/lidarlib vector/lidar/v.lidar.correction vector/lidar/v.lidar.edgedetection vector/lidar/v.outlier vector/lidar/v.surf.bspline vector/v.edit vector/v.in.sites vector/v.label.sa vector/v.net vector/v.net.alloc vector/v.net.iso vector/v.net.steiner vector/v.out.ascii vector/v.out.vtk vector/v.surf.rst visualization/nviz/src visualization/nviz2/cmd

svn_grass at osgeo.org svn_grass at osgeo.org
Wed Oct 8 22:55:41 EDT 2008


Author: glynn
Date: 2008-10-08 22:55:41 -0400 (Wed, 08 Oct 2008)
New Revision: 33769

Modified:
   grass/trunk/display/d.zoom/main.c
   grass/trunk/doc/vector/v.example/main.c
   grass/trunk/general/g.access/main.c
   grass/trunk/general/g.proj/datumtrans.c
   grass/trunk/gui/wxpython/vdigit/cats.cpp
   grass/trunk/imagery/i.cluster/open_files.c
   grass/trunk/imagery/i.fft/main.c
   grass/trunk/imagery/i.ifft/main.c
   grass/trunk/imagery/i.ortho.photo/photo.2target/main.c
   grass/trunk/imagery/i.zc/main.c
   grass/trunk/lib/gis/ls.c
   grass/trunk/lib/gis/raster.c
   grass/trunk/lib/gmath/del2g.c
   grass/trunk/lib/gpde/N_arrays_calc.c
   grass/trunk/lib/proj/convert.c
   grass/trunk/lib/vector/Vlib/break_lines.c
   grass/trunk/lib/vector/Vlib/build_nat.c
   grass/trunk/lib/vector/Vlib/net.c
   grass/trunk/raster/r.cost/main.c
   grass/trunk/raster/r.distance/defs.h
   grass/trunk/raster/r.lake/main.c
   grass/trunk/raster/r.random.cells/indep.c
   grass/trunk/raster/r.texture/main.c
   grass/trunk/raster/r.walk/main.c
   grass/trunk/raster/simwe/r.sim.sediment/main.c
   grass/trunk/raster/wildfire/r.spread/main.c
   grass/trunk/raster/wildfire/r.spreadpath/main.c
   grass/trunk/vector/lidar/lidarlib/PolimiFunct.h
   grass/trunk/vector/lidar/lidarlib/zones.c
   grass/trunk/vector/lidar/v.lidar.correction/main.c
   grass/trunk/vector/lidar/v.lidar.edgedetection/main.c
   grass/trunk/vector/lidar/v.outlier/main.c
   grass/trunk/vector/lidar/v.surf.bspline/main.c
   grass/trunk/vector/v.edit/main.c
   grass/trunk/vector/v.in.sites/main.c
   grass/trunk/vector/v.label.sa/main.c
   grass/trunk/vector/v.net.alloc/main.c
   grass/trunk/vector/v.net.iso/main.c
   grass/trunk/vector/v.net.steiner/main.c
   grass/trunk/vector/v.net/main.c
   grass/trunk/vector/v.out.ascii/main.c
   grass/trunk/vector/v.out.vtk/main.c
   grass/trunk/vector/v.surf.rst/main.c
   grass/trunk/visualization/nviz/src/nviz_init.c
   grass/trunk/visualization/nviz2/cmd/vector.c
Log:
Fix typos


Modified: grass/trunk/display/d.zoom/main.c
===================================================================
--- grass/trunk/display/d.zoom/main.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/display/d.zoom/main.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -228,7 +228,7 @@
 	map = G_find_file("windows", "previous_zoom", "");
 
 	if (!map)
-	    G_fatal_error(_("No previous zoom availible"));
+	    G_fatal_error(_("No previous zoom available"));
 
 	G__get_window(&tmpwin, "windows", "previous_zoom", map);
 

Modified: grass/trunk/doc/vector/v.example/main.c
===================================================================
--- grass/trunk/general/g.access/main.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/general/g.access/main.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -64,7 +64,7 @@
 
     /* get the current permissions */
     if (get_perms(path, &perms, &group, &other) < 0)
-	G_fatal_error(_("Unable to determine mapset permssions"));
+	G_fatal_error(_("Unable to determine mapset permissions"));
 
     if (group_opt->answer) {
 	if (group_opt->answer[0] == 'g')

Modified: grass/trunk/general/g.proj/datumtrans.c
===================================================================
--- grass/trunk/general/g.proj/datumtrans.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/general/g.proj/datumtrans.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -49,7 +49,7 @@
 
     status = GPJ__get_datum_params(projinfo, &datum, &params);
     if (datum) {
-	/* A datum name is specifed; need to determine if
+	/* A datum name is specified; need to determine if
 	 * there are parameters to choose from for this datum */
 
 	if (GPJ_get_datum_by_name(datum, &dstruct) > 0) {

Modified: grass/trunk/gui/wxpython/vdigit/cats.cpp
===================================================================
--- grass/trunk/gui/wxpython/vdigit/cats.cpp	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/gui/wxpython/vdigit/cats.cpp	2008-10-09 02:55:41 UTC (rev 33769)
@@ -108,7 +108,7 @@
    \param layer layer number
    \param cats  category number to be set
 
-   \return previosly set category
+   \return previously set category
    \return -1 if layer not available
 */
 int Digit::SetCategory(int layer, int cat)

Modified: grass/trunk/imagery/i.cluster/open_files.c
===================================================================
--- grass/trunk/imagery/i.cluster/open_files.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/imagery/i.cluster/open_files.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -58,17 +58,17 @@
     if (insigfile) {
 	fd = I_fopen_signature_file_old(group, subgroup, insigfile);
 	if (fd == NULL)
-	    G_fatal_error(_("** Can't open seed singature file <%s> **"),
+	    G_fatal_error(_("Can't open seed signature file <%s>"),
 			  insigfile);
 
 	n = I_read_signatures(fd, &in_sig);
 	fclose(fd);
 	if (n < 0)
-	    G_fatal_error(_("** Can't read signature file <%s> **"),
+	    G_fatal_error(_("Can't read signature file <%s>"),
 			  insigfile);
 
 	if (in_sig.nsigs > 255)
-	    G_fatal_error(_("** <%s> has too many signatures (limit is 255)"),
+	    G_fatal_error(_("<%s> has too many signatures (limit is 255)"),
 			  insigfile);
 
 	maxclass = in_sig.nsigs;

Modified: grass/trunk/imagery/i.fft/main.c
===================================================================
--- grass/trunk/imagery/i.fft/main.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/imagery/i.fft/main.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -147,8 +147,6 @@
      */
     data[0] = (double *)G_malloc((rows * cols) * sizeof(double));
     data[1] = (double *)G_malloc((rows * cols) * sizeof(double));
-    if (data[0] == NULL || data[1] == NULL)
-	G_fatal_error(_("Insufficent memory for allocation of data structure"));
 
     /* Initialize real & complex components to zero */
     G_message(_("Initializing data...\n"));

Modified: grass/trunk/imagery/i.ifft/main.c
===================================================================
--- grass/trunk/imagery/i.ifft/main.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/imagery/i.ifft/main.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -125,8 +125,6 @@
      */
     data[0] = (double *)G_malloc((rows * cols) * sizeof(double));
     data[1] = (double *)G_malloc((rows * cols) * sizeof(double));
-    if (data[0] == NULL || data[1] == NULL)
-	G_fatal_error(_("Insufficent memory for allocation of data structure"));
 
     /* Initialize real & complex components to zero */
     G_message(_("Reading the raster maps..."));

Modified: grass/trunk/imagery/i.ortho.photo/photo.2target/main.c
===================================================================
--- grass/trunk/imagery/i.ortho.photo/photo.2target/main.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/imagery/i.ortho.photo/photo.2target/main.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -57,13 +57,13 @@
     map_opt = G_define_standard_option(G_OPT_R_MAP);
     map_opt->required = NO;
     map_opt->description = _("Name of image to be rectified which will "
-			     " be initialy drawn on screen.");
+			     " be initially drawn on screen.");
 
     target_map_opt = G_define_standard_option(G_OPT_R_MAP);
     target_map_opt->key = "target";
     target_map_opt->required = NO;
     target_map_opt->description = _("Name of a map from target mapset which "
-				    " will be initialy drawn on screen.");
+				    " will be initially drawn on screen.");
 
     if (G_parser(argc, argv))
 	exit(1);

Modified: grass/trunk/imagery/i.zc/main.c
===================================================================
--- grass/trunk/imagery/i.zc/main.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/imagery/i.zc/main.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -141,8 +141,6 @@
      */
     data[0] = (double *)G_malloc(totsize * sizeof(double));
     data[1] = (double *)G_malloc(totsize * sizeof(double));
-    if (data[0] == NULL || data[1] == NULL)
-	G_fatal_error(_("Insufficent memory for allocation of data structure"));
 
     /* Initialize real & complex components to zero */
     G_message(_("Initializing data..."));

Modified: grass/trunk/lib/gis/ls.c
===================================================================
--- grass/trunk/lib/gis/ls.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/lib/gis/ls.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -134,7 +134,7 @@
  * \brief Prints a listing of items to a stream, in prettified column format
  * 
  * Lists the contents of the array passed to the given stream, e.g. stderr.
- * Prints the number of items specifed by "perline" to each line, unless
+ * Prints the number of items specified by "perline" to each line, unless
  * perline is given as 0 in which case the function tries to determine an 
  * appropriate column width to keep the number of lines used to a minimum
  * and look pretty on the screen.

Modified: grass/trunk/lib/gis/raster.c
===================================================================
--- grass/trunk/lib/gis/raster.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/lib/gis/raster.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -230,7 +230,7 @@
  * converts it to CELL type and returns the result.
  * If null value is stored in p, returns CELL null value.
  *
- * Used for retreiving CELL values from raster cells of any type.
+ * Used for retrieving CELL values from raster cells of any type.
  *
  * NOTE: when data_type != CELL_TYPE, no quantization is used, only
  * type conversion.
@@ -268,7 +268,7 @@
  * converts it to FCELL type and returns the result.
  * If null value is stored in p, returns FCELL null value.
  *
- * Used for retreiving FCELL values from raster cells of any type.
+ * Used for retrieving FCELL values from raster cells of any type.
  *
  *  \param p
  *  \param data_type
@@ -303,7 +303,7 @@
  * converts it to DCELL type and returns the result.
  * If null value is stored in p, returns DCELL null value.
 
- * Used for retreiving DCELL values from raster cells of any type.
+ * Used for retrieving DCELL values from raster cells of any type.
  *
  *  \param p
  *  \param data_type

Modified: grass/trunk/lib/gmath/del2g.c
===================================================================
--- grass/trunk/lib/gmath/del2g.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/lib/gmath/del2g.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -53,9 +53,6 @@
     g[0] = (double *)G_malloc(size * size * sizeof(double));
     g[1] = (double *)G_malloc(size * size * sizeof(double));
 
-    if (g[0] == NULL || g[1] == NULL)
-	G_fatal_error(_("Insufficent memory for allocation of gaussian"));
-
     G_message(_("    computing del**2 g..."));
     getg(w, g, size);
 

Modified: grass/trunk/lib/gpde/N_arrays_calc.c
===================================================================
--- grass/trunk/lib/gpde/N_arrays_calc.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/lib/gpde/N_arrays_calc.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -284,7 +284,7 @@
  * If a division with zero is detected, the resulting arrays 
  * value will set to null and not to NaN.
  * <br><br>
- * The result array is optional, if the result arrays poins to NULL,
+ * The result array is optional, if the result arrays points to NULL,
  * a new array will be allocated with the largest arrays data type
  * (CELL, FCELL or DCELL) used by the input arrays.
  * <br><br>
@@ -714,7 +714,7 @@
  * value will set to null and not to NaN.
  * <br><br>
  *
- * The result array is optional, if the result arrays poins to NULL,
+ * The result array is optional, if the result arrays points to NULL,
  * a new array will be allocated with the largest arrays data type
  * (FCELL_TYPE or DCELL_TYPE) used by the input arrays.
  * <br><br>

Modified: grass/trunk/lib/proj/convert.c
===================================================================
--- grass/trunk/lib/proj/convert.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/lib/proj/convert.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -34,7 +34,7 @@
 /**
  * \brief Converts a GRASS co-ordinate system representation to WKT style.
  * 
- * Takes a GRASS co-ordinate system as specifed by two sets of key/value
+ * Takes a GRASS co-ordinate system as specified by two sets of key/value
  * pairs derived from the PROJ_INFO and PROJ_UNITS files, and converts it
  * to the 'Well Known Text' format popularised by proprietary GIS
  * 

Modified: grass/trunk/lib/vector/Vlib/break_lines.c
===================================================================
--- grass/trunk/lib/vector/Vlib/break_lines.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/lib/vector/Vlib/break_lines.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -113,7 +113,7 @@
     /* Go through all lines in vector, for each select lines which overlap MBR of
      * this line exclude those connected by one endpoint (see above)
      * and try to intersect, if lines intersect write new lines at the end of 
-     * the file, and process next line (remainining lines overlaping box are skipped)
+     * the file, and process next line (remaining lines overlapping box are skipped)
      */
     nbreaks = 0;
     printed = 0;

Modified: grass/trunk/lib/vector/Vlib/build_nat.c
===================================================================
--- grass/trunk/lib/vector/Vlib/build_nat.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/lib/vector/Vlib/build_nat.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -193,7 +193,7 @@
 	/* Check box */
 	/* Note: If build is run on large files of areas imported from nontopo format (shapefile)
 	 * attaching of isles takes very  long time because each area is also isle and select by
-	 * box all overlaping areas selects all areas with box overlaping first node. 
+	 * box all overlapping areas selects all areas with box overlapping first node. 
 	 * Then reading coordinates for all those areas would take a long time -> check first 
 	 * if isle's box is completely within area box */
 	Vect_get_area_box(Map, area, &abox);

Modified: grass/trunk/lib/vector/Vlib/net.c
===================================================================
--- grass/trunk/lib/vector/Vlib/net.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/lib/vector/Vlib/net.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -143,7 +143,7 @@
     Map->edge_fcosts = (double *)G_malloc((nlines + 1) * sizeof(double));
     Map->edge_bcosts = (double *)G_malloc((nlines + 1) * sizeof(double));
     Map->node_costs = (double *)G_malloc((nnodes + 1) * sizeof(double));
-    /* Set to -1 initialy */
+    /* Set to -1 initially */
     for (i = 1; i <= nlines; i++) {
 	Map->edge_fcosts[i] = -1;	/* forward */
 	Map->edge_bcosts[i] = -1;	/* backward */

Modified: grass/trunk/raster/r.cost/main.c
===================================================================
--- grass/trunk/raster/r.cost/main.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/raster/r.cost/main.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -31,9 +31,9 @@
  *     1) Cost of traversing each grid cell as given by a cost map
  *        cell (input).
  *     2) If starting points are not specified on the command line
- *        then the ouput map must exist and contain the starting locations
+ *        then the output map must exist and contain the starting locations
  *
- *        Otherwise the ouput map need not exist and the coor points
+ *        Otherwise the output map need not exist and the coor points
  *        from the command line are used.
  *
  *********************************************************************/

Modified: grass/trunk/raster/r.distance/defs.h
===================================================================
--- grass/trunk/raster/r.distance/defs.h	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/raster/r.distance/defs.h	2008-10-09 02:55:41 UTC (rev 33769)
@@ -50,7 +50,7 @@
     struct Map map1, map2;	/* two raster maps to analyze */
     int labels;			/* boolean: report includes cat labels */
     char *fs;			/* report field separator     */
-    int overlap;		/* checking for overlaping, than distance is 0 */
+    int overlap;		/* checking for overlapping, than distance is 0 */
 };
 
 /* distance.c */

Modified: grass/trunk/raster/r.lake/main.c
===================================================================
--- grass/trunk/raster/r.lake/main.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/raster/r.lake/main.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -191,7 +191,7 @@
 	exit(EXIT_FAILURE);
 
     if (smap_opt->answer && sdxy_opt->answer)
-	G_fatal_error(_("Both seed map and coordinates cannot be specifed"));
+	G_fatal_error(_("Both seed map and coordinates cannot be specified"));
 
     if (!smap_opt->answer && !sdxy_opt->answer)
 	G_fatal_error(_("Seed map or seed coordinates must be set!"));
@@ -200,7 +200,7 @@
 	G_fatal_error(_("Seed coordinates and output map lake= must be set!"));
 
     if (lake_opt->answer && overwrite_flag->answer)
-	G_fatal_error(_("Both lake and overwrite cannot be specifed"));
+	G_fatal_error(_("Both lake and overwrite cannot be specified"));
 
     if (!lake_opt->answer && !overwrite_flag->answer)
 	G_fatal_error(_("Output lake map or overwrite flag must be set!"));

Modified: grass/trunk/raster/r.random.cells/indep.c
===================================================================
--- grass/trunk/raster/r.random.cells/indep.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/raster/r.random.cells/indep.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -129,7 +129,7 @@
 	}
     }
 
-    FUNCTION(outputing);
+    FUNCTION(outputting);
     OutFD = G_open_cell_new(Output->answer);
     if (OutFD < 0)
 	G_fatal_error("%s: unable to open new raster map [%s]",

Modified: grass/trunk/raster/r.texture/main.c
===================================================================
--- grass/trunk/raster/r.texture/main.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/raster/r.texture/main.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -81,7 +81,7 @@
     output->type = TYPE_STRING;
     output->required = YES;
     output->gisprompt = "new,cell,raster";
-    output->description = _("Prefix for ouput raster map(s)");
+    output->description = _("Prefix for output raster map(s)");
 
     size_O = G_define_option();
     size_O->key = "size";

Modified: grass/trunk/raster/r.walk/main.c
===================================================================
--- grass/trunk/raster/r.walk/main.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/raster/r.walk/main.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -44,9 +44,9 @@
  *     1) Cost of traversing each grid cell as given by an elevation map and
  *        a cost map cell (inputcost).
  *     2) If starting points are not specified on the command line
- *        then the ouput map must exist and contain the starting locations
+ *        then the output map must exist and contain the starting locations
  *     
- *        Otherwise the ouput map need not exist and the coor points
+ *        Otherwise the output map need not exist and the coor points
  *        from the command line are used.
  *
  *********************************************************************/

Modified: grass/trunk/raster/simwe/r.sim.sediment/main.c
===================================================================
--- grass/trunk/raster/simwe/r.sim.sediment/main.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/raster/simwe/r.sim.sediment/main.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -349,7 +349,7 @@
 
     if ((tc == NULL) && (et == NULL) && (conc == NULL) && (flux == NULL) &&
 	(erdep == NULL))
-	G_warning(_("You are not outputing any raster or site files"));
+	G_warning(_("You are not outputting any raster or site files"));
     ret_val = input_data();
     if (ret_val != 1)
 	G_fatal_error(_("Input failed"));

Modified: grass/trunk/raster/wildfire/r.spread/main.c
===================================================================
--- grass/trunk/raster/wildfire/r.spread/main.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/raster/wildfire/r.spread/main.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -219,7 +219,7 @@
     parm.x_out->gisprompt = "new,cell,raster";
     parm.x_out->guisection = _("Output_maps");
     parm.x_out->description =
-	_("Name of raster map to contain X_BACK coordiates");
+	_("Name of raster map to contain X_BACK coordinates");
 
     parm.y_out = G_define_option();
     parm.y_out->key = "y_output";
@@ -227,7 +227,7 @@
     parm.y_out->gisprompt = "new,cell,raster";
     parm.y_out->guisection = _("Output_maps");
     parm.y_out->description =
-	_("Name of raster map to contain Y_BACK coordiates");
+	_("Name of raster map to contain Y_BACK coordinates");
 
     flag.display = G_define_flag();
     flag.display->key = 'd';

Modified: grass/trunk/raster/wildfire/r.spreadpath/main.c
===================================================================
--- grass/trunk/raster/wildfire/r.spreadpath/main.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/raster/wildfire/r.spreadpath/main.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -104,7 +104,7 @@
     opt2->required = YES;
     opt2->gisprompt = "old,cell,raster";
     opt2->description =
-	_("Name of raster map containing back-path norhting information");
+	_("Name of raster map containing back-path northing information");
 
     opt3 = G_define_option();
     opt3->key = "coordinate";
@@ -123,7 +123,7 @@
 
     flag1 = G_define_flag();
     flag1->key = 'v';
-    flag1->description = _("Run verbosly");
+    flag1->description = _("Run verbosely");
 
     /*   Do command line parsing    */
     if (G_parser(argc, argv))

Modified: grass/trunk/vector/lidar/lidarlib/PolimiFunct.h
===================================================================
--- grass/trunk/vector/lidar/lidarlib/PolimiFunct.h	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/vector/lidar/lidarlib/PolimiFunct.h	2008-10-09 02:55:41 UTC (rev 33769)
@@ -32,7 +32,7 @@
 
 #define NSPLX_MAX 		200	/* Maximum number of splines along East direction used in the subregions interpolation */
 #define NSPLY_MAX		200	/* Maximum number of splines along North direction used in the subregions interpolation */
-#define OVERLAP_SIZE 		20	/* Subregions overlaping size. */
+#define OVERLAP_SIZE 		20	/* Subregions overlapping size. */
 #define LATO 			2000	/* Side's size for v.to.qrast command. */
 #define CONTOUR		15 /**/
 #define GENERAL_ROW 		0
@@ -71,7 +71,7 @@
 {
     double orlo_h;		/*Horizontal tile edge */
     double orlo_v;		/*Vertical tile edge */
-    double overlap;		/*Tile's overlaping size */
+    double overlap;		/*Tile's overlapping size */
     double latoN;		/*South-North side size */
     double latoE;		/*East-West side size */
 };

Modified: grass/trunk/vector/lidar/lidarlib/zones.c
===================================================================
--- grass/trunk/vector/lidar/lidarlib/zones.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/vector/lidar/lidarlib/zones.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -26,7 +26,7 @@
 P_set_regions(struct Cell_head *Elaboration, BOUND_BOX * General,
 	      BOUND_BOX * Overlap, struct Reg_dimens dim, int type)
 {
-    /* Set the Elaborationoration region limits-> Also set the limits of the orlo and overlaping regions->
+    /* Set the Elaborationoration region limits-> Also set the limits of the orlo and overlapping regions->
      * Returns 0 on success; -1 on failure*/
     struct Cell_head orig;
 

Modified: grass/trunk/vector/lidar/v.lidar.correction/main.c
===================================================================
--- grass/trunk/vector/lidar/v.lidar.correction/main.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/vector/lidar/v.lidar.correction/main.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -185,7 +185,7 @@
 
     /* Fixxing parameters of the elaboration region */
     /*! Each original_region will be divided into several subregions. These
-     *  subregion will be overlaped by its neibourgh subregions. This overlaping
+     *  subregion will be overlaped by its neibourgh subregions. This overlapping
      *  is calculated as OVERLAP_PASS times the east-west resolution. */
 
     nrows = G_window_rows();

Modified: grass/trunk/vector/lidar/v.lidar.edgedetection/main.c
===================================================================
--- grass/trunk/vector/v.edit/main.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/vector/v.edit/main.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -128,7 +128,7 @@
 	    if (strcmp(
 		    G_fully_qualified_name(params.map->answer, G_mapset()),
 		    G_fully_qualified_name(bmap, mapset)) == 0) {
-		G_fatal_error(_("Unable to open vector map <%s> as the backround map. "
+		G_fatal_error(_("Unable to open vector map <%s> as the background map. "
 			       "It is given as vector map to be edited."),
 			      bmap);
 	    }

Modified: grass/trunk/vector/v.in.sites/main.c
===================================================================
--- grass/trunk/vector/v.in.sites/main.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/vector/v.in.sites/main.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -180,7 +180,7 @@
 		      fi->table);
 
     /* Convert */
-    G_verbose_message(_("Transfering sites to vector point map..."));
+    G_verbose_message(_("Transferring sites to vector point map..."));
 
     count = 0;
     rewind(site);

Modified: grass/trunk/vector/v.label.sa/main.c
===================================================================
--- grass/trunk/vector/v.label.sa/main.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/vector/v.label.sa/main.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -3,7 +3,7 @@
  * MODULE:       v.label.sa
  * AUTHOR(S):    Wolf Bergenheim
  * PURPOSE:      Create paint labels, but use a Simulated Annealing
- *               algorithm to avoid overlaping labels.
+ *               algorithm to avoid overlapping labels.
  *               This file contains the command line parsing and main function.
  *               The paint label file writing funtion (print_label()) is also
  *               part of this file.

Modified: grass/trunk/vector/v.net/main.c
===================================================================
--- grass/trunk/vector/v.net/main.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/vector/v.net/main.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -114,7 +114,7 @@
     else if (strcmp(action->answer, "nreport") == 0)
 	act = TOOL_NREPORT;
     else
-	G_fatal_error(_("Unknow operation"));
+	G_fatal_error(_("Unknown operation"));
 
     if (act == TOOL_NODES || act == TOOL_CONNECT) {
 	if (output->answer == NULL)

Modified: grass/trunk/vector/v.net.alloc/main.c
===================================================================
--- grass/trunk/vector/v.net.alloc/main.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/vector/v.net.alloc/main.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -31,8 +31,8 @@
 
 typedef struct
 {
-    int centre;			/* neares centre, initialy -1 */
-    double cost;		/* costs from this centre, initialy not undefined */
+    int centre;			/* neares centre, initially -1 */
+    double cost;		/* costs from this centre, initially not undefined */
 } NODE;
 
 int main(int argc, char **argv)

Modified: grass/trunk/vector/v.net.iso/main.c
===================================================================
--- grass/trunk/vector/v.net.iso/main.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/vector/v.net.iso/main.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -31,8 +31,8 @@
 
 typedef struct
 {
-    int centre;			/* neares centre, initialy -1 *//* currently not used */
-    double cost;		/* costs from this centre, initialy not undefined */
+    int centre;			/* neares centre, initially -1 *//* currently not used */
+    double cost;		/* costs from this centre, initially not undefined */
 } NODE;
 
 typedef struct
@@ -443,7 +443,7 @@
 	    }
 	    G_debug(3, "  npnts2 cut = %d", npnts2);
 
-	    /* Biggest cost shoud be equal if exist (npnts > 0). Cut out overlaping segments,
+	    /* Biggest cost shoud be equal if exist (npnts > 0). Cut out overlapping segments,
 	     *  this can cut only points on line but not first points */
 	    if (npnts1 > 1 && npnts2 > 1) {
 		while (npnts1 > 1 && npnts2 > 1) {

Modified: grass/trunk/vector/v.net.steiner/main.c
===================================================================
--- grass/trunk/vector/v.out.ascii/main.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/vector/v.out.ascii/main.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -120,7 +120,7 @@
     /*The precision of the output */
     if (dp_opt->answer) {
 	if (sscanf(dp_opt->answer, "%d", &dp) != 1)
-	    G_fatal_error(_("Failed to interprete 'dp' parameter as an integer"));
+	    G_fatal_error(_("Failed to interpret 'dp' parameter as an integer"));
     }
 
 

Modified: grass/trunk/vector/v.out.vtk/main.c
===================================================================
--- grass/trunk/vector/v.out.vtk/main.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/vector/v.out.vtk/main.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -173,7 +173,7 @@
     /*The precision of the output */
     if (dp_opt->answer) {
 	if (sscanf(dp_opt->answer, "%d", &dp) != 1)
-	    G_fatal_error(_("Failed to interprete 'dp' parameter as an integer"));
+	    G_fatal_error(_("Failed to interpret 'dp' parameter as an integer"));
 	if (dp > 8 || dp < 0)
 	    G_fatal_error(_("dp has to be from 0 to 8"));
     }
@@ -184,7 +184,7 @@
     /*The Layer */
     if (layer_opt->answer) {
 	if (sscanf(layer_opt->answer, "%d", &layer) != 1)
-	    G_fatal_error(_("Failed to interprete 'layer' parameter as an integer"));
+	    G_fatal_error(_("Failed to interpret 'layer' parameter as an integer"));
     }
     else {
 	layer = 1;

Modified: grass/trunk/vector/v.surf.rst/main.c
===================================================================
--- grass/trunk/vector/v.surf.rst/main.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/vector/v.surf.rst/main.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -387,7 +387,7 @@
 	&& (mcurv == NULL)
 	&& (slope == NULL) && (aspect == NULL) && (devi == NULL)
 	&& (cvdev == NULL))
-	G_warning(_("You are not outputing any raster or vector maps"));
+	G_warning(_("You are not outputting any raster or vector maps"));
 
     if (parm.wheresql->answer != NULL) {
 	if (field < 1)

Modified: grass/trunk/visualization/nviz/src/nviz_init.c
===================================================================
--- grass/trunk/visualization/nviz/src/nviz_init.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/visualization/nviz/src/nviz_init.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -127,7 +127,7 @@
     state->key = "state";
     state->type = TYPE_STRING;
     state->required = NO;
-    state->description = _("Load previosly saved state file");
+    state->description = _("Load previously saved state file");
 
     jj = 0;
     /*

Modified: grass/trunk/visualization/nviz2/cmd/vector.c
===================================================================
--- grass/trunk/visualization/nviz2/cmd/vector.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/visualization/nviz2/cmd/vector.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -178,7 +178,7 @@
 	else if (strcmp(marker_str, "histogram") == 0)
 	    marker = ST_HISTOGRAM;
 	else
-	    G_fatal_error(_("Unknow icon marker"));
+	    G_fatal_error(_("Unknown icon marker"));
 
 	GP_set_sitemode(site_list[i], ST_ATT_NONE,
 			color, width, size, marker);



More information about the grass-commit mailing list
--- grass/trunk/doc/vector/v.example/main.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/doc/vector/v.example/main.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -156,7 +156,7 @@
 	    printf("No:%d\tX:%f\tY:%f\tZ:%f\tCAT:%d\n", i, *Points->x,
 		   *Points->y, *Points->z, cat);
 
 	    /* Prepeare SQL query to get point atribute data */
 	    sprintf(sql, "select * from %s where %s=%d", Fi->table, Fi->key,
 		    cat);
 	    G_debug(1, "SQL: \"%s\"", sql);
@@ -173,7 +173,7 @@
 		/* Let's output every columns name and value */
 		while (1) {
 		    if (db_fetch(&cursor, DB_NEXT, &more) != DB_OK) {
-			G_warning(_("Error while retreiving database record for cat %d"),
+			G_warning(_("Error while retrieving database record for cat %d"),
 				  cat);
 			break;
 		    }
@@ -202,11 +202,11 @@
 	    Fin->number, Fin->name, Fin->driver, Fin->database, Fin->table,
 	    Fin->key);
 
     /* Let's copy atribute table data */
     if (db_copy_table(Fi->driver, Fi->database, Fi->table,
 		      Fin->driver, Vect_subst_var(Fin->database, &Out),
 		      Fin->table) == DB_FAILED)
-	G_warning(_("Unable to copy atribute table to vector map <%s>"),
+	G_warning(_("Unable to copy attribute table to vector map <%s>"),
 		  new->answer);
     else
 	Vect_map_add_dblink(&Out, Fin->number, Fin->name, Fin->table, Fi->key,
@@ -156,7 +156,7 @@
 		   *Points->y, *Points->z, cat);
 
-	    /* Prepeare SQL query to get point atribute data */
+	    /* Prepeare SQL query to get point attribute data */
 	    sprintf(sql, "select * from %s where %s=%d", Fi->table, Fi->key,
 		    cat);
@@ -202,11 +202,11 @@
 	    Fin->key);
 
-    /* Let's copy atribute table data */
+    /* Let's copy attribute table data */
     if (db_copy_table(Fi->driver, Fi->database, Fi->table,
 		      Fin->driver, Vect_subst_var(Fin->database, &Out),

Modified: grass/trunk/general/g.access/main.c
===================================================================
--- grass/trunk/vector/lidar/v.lidar.edgedetection/main.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/vector/lidar/v.lidar.edgedetection/main.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -203,7 +203,7 @@
 
     /* Fixxing parameters of the elaboration region */
     /*! Each original_region will be divided into several subregions. These
      *  subregion will be overlaped by its neibourgh subregions. This overlaping
      *  is calculated as OVERLAP_PASS times the east-west resolution. */
 
     ew_resol = original_reg.ew_res;
@@ -340,7 +340,7 @@
 
 		if (flag_auxiliar == FALSE) {
 		    G_debug(1,
-			    _("Creating auxiliar table for archiving overlaping zones"));
+			    _("Creating auxiliar table for archiving overlapping zones"));
 		    if ((flag_auxiliar =
 			 Create_AuxEdge_Table(driver)) == FALSE)
 			G_fatal_error(_("It was impossible to create <%s>."),
@@ -203,7 +203,7 @@
     /* Fixxing parameters of the elaboration region */
     /*! Each original_region will be divided into several subregions. These
-     *  subregion will be overlaped by its neibourgh subregions. This overlaping
+     *  subregion will be overlapped by its neibourgh subregions. This overlapping
      *  is calculated as OVERLAP_PASS times the east-west resolution. */
 

Modified: grass/trunk/vector/lidar/v.outlier/main.c
===================================================================
--- grass/trunk/vector/lidar/v.outlier/main.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/vector/lidar/v.outlier/main.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -197,7 +197,7 @@
 
     /* Fixxing parameters of the elaboration region */
     /*! Each original_region will be divided into several subregions. These
      *  subregion will be overlaped by its neibourgh subregions. This overlaping
      *  is calculated as OVERLAP_PASS times the east-west resolution. */
 
     ew_resol = original_reg.ew_res;
@@ -313,7 +313,7 @@
 
 		if (flag_auxiliar == FALSE) {
 		    G_debug(1,
-			    "Creating auxiliar table for archiving overlaping zones");
+			    "Creating auxiliar table for archiving overlapping zones");
 		    if ((flag_auxiliar =
 			 P_Create_Aux_Table(driver, table_name)) == FALSE)
 			G_fatal_error(_("It was impossible to create <Auxiliar_outlier_table>."));
@@ -197,7 +197,7 @@
     /* Fixxing parameters of the elaboration region */
     /*! Each original_region will be divided into several subregions. These
-     *  subregion will be overlaped by its neibourgh subregions. This overlaping
+     *  subregion will be overlapped by its neibourgh subregions. This overlapping
      *  is calculated as OVERLAP_PASS times the east-west resolution. */
 

Modified: grass/trunk/vector/lidar/v.surf.bspline/main.c
===================================================================
--- grass/trunk/vector/lidar/v.surf.bspline/main.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/vector/lidar/v.surf.bspline/main.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -399,7 +399,7 @@
       | Subdividing and working with tiles: 									
       | Each original_region will be divided into several subregions. 
       | Each one will be overlaped by its neibourgh subregions. 
-      | The overlaping was calculated as a fixed OVERLAP_SIZE times the east-west resolution
+      | The overlapping was calculated as a fixed OVERLAP_SIZE times the east-west resolution
       ------------------------------------------------------------------------------------------*/
 
     elaboration_reg.south = original_reg.north;
@@ -674,7 +674,7 @@
 	}			/*! END WHILE; last_column = TRUE */
     }				/*! END WHILE; last_row = TRUE */
 
     /* Writing into the output vector map the points from the overlaping zones */
     if (flag_auxiliar == TRUE) {
 	if (grid == FALSE) {
 	    if (ext == FALSE)
@@ -674,7 +674,7 @@
     }				/*! END WHILE; last_row = TRUE */
 
-    /* Writing into the output vector map the points from the overlaping zones */
+    /* Writing into the output vector map the points from the overlapping zones */
     if (flag_auxiliar == TRUE) {
 	if (grid == FALSE) {

Modified: grass/trunk/vector/v.edit/main.c
===================================================================
--- grass/trunk/vector/v.net.steiner/main.c	2008-10-09 01:09:04 UTC (rev 33768)
+++ grass/trunk/vector/v.net.steiner/main.c	2008-10-09 02:55:41 UTC (rev 33769)
@@ -385,7 +385,7 @@
     nsp_opt->required = NO;
     nsp_opt->multiple = NO;
     nsp_opt->answer = "-1";
-    nsp_opt->description = _("Number of steiner poins (-1 for all possible)");
+    nsp_opt->description = _("Number of steiner points (-1 for all possible)");
 
     geo_f = G_define_flag();
     geo_f->key = 'g';
@@ -525,7 +525,7 @@
     ret = mst(&Map, terms, nterms, &cost, PORT_DOUBLE_MAX, NULL, NULL, 0, 1);	/* no StP, rebuild */
     G_message(_("MST costs = %f"), cost);
 
     /* Go through all nodes and try to use as steiner poins -> find that which saves most costs */
     nspused = 0;
     for (j = 0; j < nsp; j++) {
 	sp = 0;
@@ -525,7 +525,7 @@
     G_message(_("MST costs = %f"), cost);
 
-    /* Go through all nodes and try to use as steiner poins -> find that which saves most costs */
+    /* Go through all nodes and try to use as steiner points -> find that which saves most costs */
     nspused = 0;
     for (j = 0; j < nsp; j++) {

Modified: grass/trunk/vector/v.out.ascii/main.c
===================================================================